@@ -299,7 +299,7 @@ static const PICTCode
 /*
   Forward declarations.
 */
-static unsigned int
+static MagickBooleanType
   WritePICTImage(const ImageInfo *,Image *);
 
 /*
@@ -323,9 +323,6 @@ static unsigned int
 %
 %  A description of each parameter follows:
 %
-%    o status:  Method DecodeImage returns True if all the pixels are
-%      uncompressed without error, otherwise False.
-%
 %    o image_info: The image info.
 %
 %    o blob,image: The address of a structure of type Image.
@@ -547,8 +544,6 @@ static unsigned char *DecodeImage(const ImageInfo *image_info,Image *blob,
 %
 %  A description of each parameter follows:
 %
-%    o status:  Method EncodeImage returns the number of encoded pixels.
-%
 %    o image: The address of a structure of type Image.
 %
 %    o scanline: A pointer to an array of characters to pack.
@@ -591,7 +586,7 @@ static size_t EncodeImage(Image *image,const unsigned char *scanline,
   */
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
-  if (image->debug != False)
+  if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
   assert(scanline != (unsigned char *) NULL);
   assert(pixels != (unsigned char *) NULL);
@@ -700,17 +695,15 @@ static size_t EncodeImage(Image *image,const unsigned char *scanline,
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  IsPICT()() returns True if the image format type, identified by the magick
-%  string, is PICT.
+%  IsPICT()() returns MagickTrue if the image format type, identified by the
+%  magick string, is PICT.
 %
 %  The format of the ReadPICTImage method is:
 %
-%      unsigned int IsPICT(const unsigned char *magick,const size_t length)
+%      MagickBooleanType IsPICT(const unsigned char *magick,const size_t length)
 %
 %  A description of each parameter follows:
 %
-%    o status:  Method IsPICT() returns True if the image format type is PICT.
-%
 %    o magick: This string is generally the first few bytes of an image file
 %      or blob.
 %
@@ -718,13 +711,13 @@ static size_t EncodeImage(Image *image,const unsigned char *scanline,
 %
 %
 */
-static unsigned int IsPICT(const unsigned char *magick,const size_t length)
+static MagickBooleanType IsPICT(const unsigned char *magick,const size_t length)
 {
   if (length < 528)
-    return(False);
+    return(MagickFalse);
   if (memcmp(magick+522,"\000\021\002\377\014\000",6) == 0)
-    return(True);
-  return(False);
+    return(MagickTrue);
+  return(MagickFalse);
 }
 
 #if !defined(macintosh)
@@ -750,10 +743,6 @@ static unsigned int IsPICT(const unsigned char *magick,const size_t length)
 %
 %  A description of each parameter follows:
 %
-%    o image:  Method ReadPICTImage returns a pointer to the image after
-%      reading.  A null image is returned if there is a memory shortage or
-%      if the image cannot be read.
-%
 %    o image_info: The image info.
 %
 %    o exception: return any errors or warnings in this structure.
@@ -782,6 +771,10 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
     version,
     y;
 
+  MagickBooleanType
+    jpeg,
+    status;
+
   PICTRectangle
     frame;
 
@@ -806,22 +799,18 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
   StringInfo
     *profile;
 
-  unsigned int
-    jpeg,
-    status;
-
   /*
     Open image file.
   */
   assert(image_info != (const ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
-  if (image_info->debug != False)
+  if (image_info->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
   image=AllocateImage(image_info);
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
-  if (status == False)
+  if (status == MagickFalse)
     {
       DestroyImageList(image);
       return((Image *) NULL);
@@ -855,10 +844,10 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
   /*
     Interpret PICT opcodes.
   */
-  jpeg=False;
-  for (code=0; EOFBlob(image) == False; )
+  jpeg=MagickFalse;
+  for (code=0; EOFBlob(image) == MagickFalse; )
   {
-    if ((image_info->ping != False) && (image_info->number_scenes != 0))
+    if ((image_info->ping != MagickFalse) && (image_info->number_scenes != 0))
       if (image->scene >= (image_info->scene+image_info->number_scenes-1))
         break;
     if ((version == 1) || ((TellBlob(image) % 2) != 0))
@@ -867,12 +856,12 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
       code=ReadBlobMSBShort(image);
     if (code > 0xa1)
       {
-        if (image->debug != False)
+        if (image->debug != MagickFalse)
           (void) LogMagickEvent(CoderEvent,GetMagickModule(),"%04X:",code);
       }
     else
       {
-        if (image->debug != False)
+        if (image->debug != MagickFalse)
           (void) LogMagickEvent(CoderEvent,GetMagickModule(),
             "  %04X %s: %s",code,codes[code].name,codes[code].description);
         switch (code)
@@ -1029,7 +1018,7 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
               Initialize tile image.
             */
             tile_image=CloneImage(image,frame.right-frame.left,
-              frame.bottom-frame.top,True,exception);
+              frame.bottom-frame.top,MagickTrue,exception);
             if (tile_image == (Image *) NULL)
               return((Image *) NULL);
             DestroyBlob(tile_image);
@@ -1037,8 +1026,9 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
             if ((code == 0x9a) || (code == 0x9b) || (bytes_per_line & 0x8000))
               {
                 ReadPixmap(pixmap);
-                tile_image->matte=pixmap.component_count == 4;
-                if (tile_image->matte != False)
+                tile_image->matte=
+                  pixmap.component_count == 4 ? MagickTrue : MagickFalse;
+                if (tile_image->matte != MagickFalse)
                   image->matte=tile_image->matte;
               }
             if ((code != 0x9a) && (code != 0x9b))
@@ -1054,7 +1044,7 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
                     tile_image->colors=ReadBlobMSBShort(image)+1;
                   }
                 status=AllocateImageColormap(tile_image,tile_image->colors);
-                if (status == False)
+                if (status == MagickFalse)
                   {
                     DestroyImage(tile_image);
                     ThrowReaderException(ResourceLimitError,
@@ -1144,7 +1134,7 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
                         q->blue=ScaleCharToQuantum((j & 0x1f) << 3);
                       }
                     else
-                      if (tile_image->matte == False)
+                      if (tile_image->matte == MagickFalse)
                         {
                           q->red=ScaleCharToQuantum(*p);
                           q->green=
@@ -1165,7 +1155,7 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
                 p++;
                 q++;
               }
-              if (SyncImagePixels(tile_image) == False)
+              if (SyncImagePixels(tile_image) == MagickFalse)
                 break;
               if ((tile_image->storage_class == DirectClass) &&
                   (pixmap.bits_per_pixel != 16))
@@ -1175,12 +1165,12 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
                   {
                     status=MagickMonitor(LoadImageTag,y,tile_image->rows,
                       &image->exception);
-                    if (status == False)
+                    if (status == MagickFalse)
                       break;
                   }
             }
             pixels=(unsigned char *) RelinquishMagickMemory(pixels);
-            if (jpeg == False)
+            if (jpeg == MagickFalse)
               if ((code == 0x9a) || (code == 0x9b) ||
                   ((bytes_per_line & 0x8000) != 0))
                 (void) CompositeImage(image,CopyCompositeOp,tile_image,
@@ -1190,7 +1180,7 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
               {
                 status=MagickMonitor(LoadImageTag,destination.bottom,
                   image->rows,&image->exception);
-                if (status == False)
+                if (status == MagickFalse)
                   break;
               }
             break;
@@ -1228,7 +1218,7 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
                 SetStringInfoDatum(profile,info);
                 status=SetImageProfile(image,"icc",profile);
                 DestroyStringInfo(profile);
-                if (status == False)
+                if (status == MagickFalse)
                   ThrowReaderException(ResourceLimitError,
                     "MemoryAllocationFailed");
                 break;
@@ -1239,8 +1229,8 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
                   break;
                 profile=AcquireStringInfo(length);
                 SetStringInfoDatum(profile,info);
-                status=SetImageProfile(image,"8bim",profile);
-                if (status == False)
+                status=SetImageProfile(image,"iptc",profile);
+                if (status == MagickFalse)
                   ThrowReaderException(ResourceLimitError,
                     "MemoryAllocationFailed");
                 DestroyStringInfo(profile);
@@ -1294,7 +1284,7 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
         /*
           Embedded JPEG.
         */
-        jpeg=True;
+        jpeg=MagickTrue;
         read_info=CloneImageInfo(image_info);
         read_info->blob=(void *) NULL;
         read_info->length=0;
@@ -1309,7 +1299,7 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
             ThrowFileException(exception,FileOpenError,
               "UnableToCreateTemporaryFile",image->filename);
             DestroyImageList(image);
-            return(False);
+            return((Image *) NULL);
           }
         length=ReadBlobMSBLong(image);
         for (i=0; i < 6; i++)
@@ -1398,7 +1388,7 @@ ModuleExport void RegisterPICTImage(void)
   entry=SetMagickInfo("PCT");
   entry->decoder=(DecoderHandler *) ReadPICTImage;
   entry->encoder=(EncoderHandler *) WritePICTImage;
-  entry->adjoin=False;
+  entry->adjoin=MagickFalse;
   entry->description=AcquireString("Apple Macintosh QuickDraw/PICT");
   entry->magick=(MagickHandler *) IsPICT;
   entry->module=AcquireString("PICT");
@@ -1406,7 +1396,7 @@ ModuleExport void RegisterPICTImage(void)
   entry=SetMagickInfo("PICT");
   entry->decoder=(DecoderHandler *) ReadPICTImage;
   entry->encoder=(EncoderHandler *) WritePICTImage;
-  entry->adjoin=False;
+  entry->adjoin=MagickFalse;
   entry->description=AcquireString("Apple Macintosh QuickDraw/PICT");
   entry->magick=(MagickHandler *) IsPICT;
   entry->module=AcquireString("PICT");
@@ -1454,21 +1444,18 @@ ModuleExport void UnregisterPICTImage(void)
 %
 %  The format of the WritePICTImage method is:
 %
-%      unsigned int WritePICTImage(const ImageInfo *image_info,Image *image)
+%      MagickBooleanType WritePICTImage(const ImageInfo *image_info,Image *image)
 %
 %  A description of each parameter follows.
 %
-%    o status: Method WritePICTImage return True if the image is written.
-%      False is returned is there is a memory shortage or if the image file
-%      fails to write.
-%
 %    o image_info: The image info.
 %
 %    o image:  The image.
 %
 %
 */
-static unsigned int WritePICTImage(const ImageInfo *image_info,Image *image)
+static MagickBooleanType WritePICTImage(const ImageInfo *image_info,
+  Image *image)
 {
 #define MaxCount  128
 #define PictCropRegionOp  0x01
@@ -1487,6 +1474,9 @@ static unsigned int WritePICTImage(const ImageInfo *image_info,Image *image)
   long
     y;
 
+  MagickBooleanType
+    status;
+
   MagickOffsetType
     offset;
 
@@ -1522,9 +1512,6 @@ static unsigned int WritePICTImage(const ImageInfo *image_info,Image *image)
     *packed_scanline,
     *scanline;
 
-  unsigned int
-    status;
-
   unsigned long
     bytes_per_line,
     storage_class;
@@ -1541,12 +1528,12 @@ static unsigned int WritePICTImage(const ImageInfo *image_info,Image *image)
   assert(image_info->signature == MagickSignature);
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
-  if (image->debug != False)
+  if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
   if ((image->columns > 65535L) || (image->rows > 65535L))
     ThrowWriterException(ImageError,"WidthOrHeightExceedsLimit");
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
-  if (status == False)
+  if (status == MagickFalse)
     return(status);
   (void) SetImageColorspace(image,RGBColorspace);
   /*
@@ -1582,7 +1569,7 @@ static unsigned int WritePICTImage(const ImageInfo *image_info,Image *image)
   storage_class=image->storage_class;
   if (image->compression == JPEGCompression)
     storage_class=DirectClass;
-  if ((storage_class == DirectClass) || (image->matte != False))
+  if ((storage_class == DirectClass) || (image->matte != MagickFalse))
     {
       pixmap.component_count=image->matte ? 4 : 3;
       pixmap.pixel_type=16;
@@ -1595,7 +1582,7 @@ static unsigned int WritePICTImage(const ImageInfo *image_info,Image *image)
     Allocate memory.
   */
   bytes_per_line=image->columns;
-  if ((storage_class == DirectClass) || (image->matte != False))
+  if ((storage_class == DirectClass) || (image->matte != MagickFalse))
     bytes_per_line*=image->matte ? 4 : 3;
   buffer=(unsigned char *) AcquireMagickMemory(PictInfoSize);
   packed_scanline=(unsigned char *) AcquireMagickMemory(row_bytes+MaxCount);
@@ -1632,7 +1619,7 @@ static unsigned int WritePICTImage(const ImageInfo *image_info,Image *image)
   (void) WriteBlobMSBShort(image,frame_rectangle.bottom);
   (void) WriteBlobMSBShort(image,frame_rectangle.right);
   (void) WriteBlobMSBLong(image,0x00000000L);
-  profile=GetImageProfile(image,"8bim");
+  profile=GetImageProfile(image,"iptc");
   if (profile != (StringInfo *) NULL)
     {
       (void) WriteBlobMSBShort(image,0xa1);
@@ -1674,11 +1661,11 @@ static unsigned int WritePICTImage(const ImageInfo *image_info,Image *image)
       unsigned char
         *blob;
 
-      jpeg_image=CloneImage(image,0,0,True,&image->exception);
+      jpeg_image=CloneImage(image,0,0,MagickTrue,&image->exception);
       if (jpeg_image == (Image *) NULL)
         {
           CloseBlob(image);
-          return(False);
+          return(MagickFalse);
         }
       DestroyBlob(jpeg_image);
       jpeg_image->blob=CloneBlobInfo((BlobInfo *) NULL);
@@ -1686,7 +1673,7 @@ static unsigned int WritePICTImage(const ImageInfo *image_info,Image *image)
       blob=(unsigned char *) ImageToBlob(image_info,jpeg_image,&length,
         &image->exception);
       if (blob == (unsigned char *) NULL)
-        return(False);
+        return(MagickFalse);
       DestroyImage(jpeg_image);
       (void) WriteBlobMSBShort(image,PictJPEGOp);
       (void) WriteBlobMSBLong(image,length+154);
@@ -1810,7 +1797,7 @@ static unsigned int WritePICTImage(const ImageInfo *image_info,Image *image)
     Write picture data.
   */
   count=0;
-  if ((storage_class == PseudoClass) && (image->matte == False))
+  if ((storage_class == PseudoClass) && (image->matte == MagickFalse))
     for (y=0; y < (long) image->rows; y++)
     {
       p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
@@ -1820,10 +1807,10 @@ static unsigned int WritePICTImage(const ImageInfo *image_info,Image *image)
       for (x=0; x < (long) image->columns; x++)
         scanline[x]=indexes[x];
       count+=EncodeImage(image,scanline,row_bytes & 0x7FFF,packed_scanline);
-      if (QuantumTick(y,image->rows))
+      if (QuantumTick(y,image->rows) != MagickFalse)
         {
           status=MagickMonitor(SaveImageTag,y,image->rows,&image->exception);
-          if (status == False)
+          if (status == MagickFalse)
             break;
         }
     }
@@ -1854,7 +1841,7 @@ static unsigned int WritePICTImage(const ImageInfo *image_info,Image *image)
           red=scanline;
           green=scanline+image->columns;
           blue=scanline+2*image->columns;
-          if (image->matte != False)
+          if (image->matte != MagickFalse)
             {
               opacity=scanline;
               red=scanline+image->columns;
@@ -1866,17 +1853,17 @@ static unsigned int WritePICTImage(const ImageInfo *image_info,Image *image)
             *red++=ScaleQuantumToChar(p->red);
             *green++=ScaleQuantumToChar(p->green);
             *blue++=ScaleQuantumToChar(p->blue);
-            if (image->matte != False)
+            if (image->matte != MagickFalse)
               *opacity++=ScaleQuantumToChar(MaxRGB-p->opacity);
             p++;
           }
           count+=EncodeImage(image,scanline,bytes_per_line & 0x7FFF,
             packed_scanline);
-          if (QuantumTick(y,image->rows))
+          if (QuantumTick(y,image->rows) != MagickFalse)
             {
               status=MagickMonitor(SaveImageTag,y,image->rows,
                 &image->exception);
-              if (status == False)
+              if (status == MagickFalse)
                 break;
             }
         }
@@ -1891,5 +1878,5 @@ static unsigned int WritePICTImage(const ImageInfo *image_info,Image *image)
   packed_scanline=(unsigned char *) RelinquishMagickMemory(packed_scanline);
   buffer=(unsigned char *) RelinquishMagickMemory(buffer);
   CloseBlob(image);
-  return(True);
+  return(MagickTrue);
 }
